"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPlaylistUrl = exports.getSteamUrl = exports.verifyJwtToken = exports.signJwtToken = exports.mapValues = exports.exists = void 0;
const jsonwebtoken_1 = require("jsonwebtoken");
function exists(json, key) {
    const value = json[key];
    return value !== null && value !== undefined;
}
exports.exists = exists;
function mapValues(data, fn) {
    return Object.keys(data).reduce((acc, key) => ({ ...acc, [key]: fn(data[key]) }), {});
}
exports.mapValues = mapValues;
function signJwtToken(data, key) {
    return jsonwebtoken_1.sign(data, key);
}
exports.signJwtToken = signJwtToken;
function verifyJwtToken(token, key, maxAge) {
    try {
        return jsonwebtoken_1.verify(token, key, {
            maxAge,
        });
    }
    catch (error) {
        console.log(error);
        return undefined;
    }
}
exports.verifyJwtToken = verifyJwtToken;
function getSteamUrl(torrent, file, encodeToken) {
    if (encodeToken) {
        return `/stream/${encodeURIComponent(signJwtToken({
            torrent,
            file,
        }, encodeToken))}`;
    }
    return `/stream/${encodeURIComponent(torrent)}?file=${encodeURIComponent(file)}`;
}
exports.getSteamUrl = getSteamUrl;
function getPlaylistUrl(torrent, encodeToken) {
    if (encodeToken) {
        return `/playlist/${encodeURIComponent(signJwtToken({
            torrent,
        }, encodeToken))}`;
    }
    return `/playlist/${encodeURIComponent(torrent)}`;
}
exports.getPlaylistUrl = getPlaylistUrl;
